// Variables to store video stream and recorded video blob
let stream, recorder, videoBlob;
const countdownElement = document.getElementById('countDown');
const startButton = document.getElementById('btnStart');
const stopButton = document.getElementById('btnStop');

// Down counter
function countdown(seconds) {
	countdownElement.textContent = seconds;
	if (seconds > 1) {
		setTimeout(function() {
			countdown(seconds - 1);
		}, 1000);
	} else {
		navigator.mediaDevices.getUserMedia({
				video: true,
				audio: true
			})
			.then(function(mediaStream) {
				stream = mediaStream;
				const videoElement = document.getElementById('videoPreview');
				videoElement.srcObject = stream;
				videoElement.play();

				recorder = new MediaRecorder(mediaStream);
				recorder.ondataavailable = function(event) {
					if (event.data && event.data.size > 0) {
						videoBlob = event.data;
					}
				};
				recorder.start();
				countdownElement.textContent = '';
				$(document).find('.spinner-start').removeClass('d-none');
				$(document).find('.upload-video-section').addClass('d-none');
				startButton.disabled = true;
				stopButton.disabled = false;
			})
			.catch(function(error) {
				$('#liveToast .toast-body').empty().html('Error accessing media devices: ' + error);
				$('#liveToast').toast('show');
			});
	}
}

// Function to start recording
function startRecording() {
	$('.count-down').removeClass('d-none');
	countdown(5);
}

// Function to stop recording
function stopRecording() {
	if (recorder && recorder.state !== 'inactive') {
		recorder.stop();
		stream.getTracks().forEach(function(track) {
			track.stop();
		});
		$('.spinner-start').addClass('d-none');
		$('.upload-video-section').removeClass('d-none');
		startButton.disabled = false;
		stopButton.disabled = true;
	}
}

// Function to upload the recorded video
function uploadVideo(streamName) {
	if (videoBlob) {

		const fileName = 'recording-' + Math.floor(Math.random() * 1000000) + '.webm';
		const formData = new FormData();
		formData.append('video', videoBlob, fileName); // Adjust the file name and format accordingly
		formData.append('data[indicator]', 'video_upload');
		formData.append('data[name]', streamName);

		// SHOW LOADER
		$('.spinner-upload').removeClass('d-none');

		// Send the video file to the server using AJAX or a form submission
		// Replace 'upload.php' with the actual URL of your PHP upload endpoint
		fetch('functions.php', {
				method: 'POST',
				body: formData
			})
			.then(response => response.json())
			.then(data => {

				// ASSIGN VALUE
				$('.prerecorded-video').append('<option value="' + data.sid + '" selected>' + data.name + '</option>');
				$('.video-stream').val(data.sid);
				$('.selected-video').val(data.name);

				// HIDE LOADER
				$('.spinner-upload').addClass('d-none');

				// Handle the response from the server
				$('#liveToast .toast-body').empty().html('Video uploaded successfully');
				$('#liveToast').toast('show');
			})
			.catch(function(error) {
				$('#liveToast .toast-body').empty().html('Error uploading video: ' + error);
				$('#liveToast').toast('show');
			});
	}
}

$(document).ready(function() {

	var selectedCountry = $('.country').val();
	if (selectedCountry) {
		$('#country').val(selectedCountry);
	}

	// USER LOGIN
	$('.login-form').validate({
		rules: {
			'data[email]': {
				required: true,
				email: true
			},
			'data[password]': {
				required: true
			}
		},
		messages: {
			'data[email]': {
				required: 'Need your email to contact',
				email: 'Please enter a valid email'
			},
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var loginData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: loginData
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					window.location.href = 'dashboard.php?token=' + resp.token;
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// USER LOGIN
	$('.password-form').validate({
		rules: {
			'data[password]': {
				required: true
			}
		},
		messages:{
			'data[password]': {
				required: 'Password is required'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET NJT CUSTOMER MAIL
			var passwordData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: passwordData
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					location.reload();
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// USER REGISTRATION
	$('.register-form').validate({
		rules: {
			'data[first_name]': {
				required: true
			},
			'data[last_name]': {
				required: true
			},
			'data[email]': {
				required: true,
				email: true
			},
			'data[country]': {
				required: true
			},
			'data[anoviteid]': {
				required: true
			}
		},
		messages: {
			'data[first_name]': {
				required: 'Please enter your firstname'
			},
			'data[last_name]': {
				required: 'Please enter your lastname'
			},
			'data[email]': {
				required: 'Need your email to contact',
				email: 'Please enter a valid email'
			},
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var registerData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: registerData
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					window.location.href = 'dashboard.php?token=' + resp.token;
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// EDIT USER
	$('.edituser-form').validate({
		rules: {
			'data[first_name]': {
				required: true
			},
			'data[last_name]': {
				required: true
			},
			'data[email]': {
				required: true,
				email: true
			},
			'data[country]': {
				required: true
			}
		},
		messages: {
			'data[first_name]': {
				required: 'Please enter your firstname'
			},
			'data[last_name]': {
				required: 'Please enter your lastname'
			},
			'data[email]': {
				required: 'Need your email to contact',
				email: 'Please enter a valid email'
			},
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var userData = new FormData(form);

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: userData,
				cache: false,
				contentType: false,
				processData: false
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					window.location.href = 'dashboard.php?token=' + resp.token;
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// UPLOAD CSV
	$('.csvupload-form').validate({
		rules: {
			'data[list_id]': {
				required: true
			},
			'data[csvfile]': {
				required: true
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var loginData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: loginData,
				cache: false,
				contentType: false,
				processData: false
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					var setTime = setTimeout(function(){
						window.location.href = 'contacts.php?token=' + resp.token;
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// ADD LIST
	$('.addlist-form').validate({
		rules: {
			'data[name]': {
				required: true
			}
		},
		messages: {
			'data[name]': {
				required: 'Please enter a list name'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var leadlistData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: leadlistData
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					window.location.href = 'lists.php?token=' + resp.token;
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// EDIT LIST
	$('.editlist-form').validate({
		rules: {
			'data[name]': {
				required: true
			}
		},
		messages: {
			'data[name]': {
				required: 'Please enter a list name'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var leadlistData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: leadlistData
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					window.location.href = 'lists.php?token=' + resp.token;
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// DELETE LIST
	$(document).on('click', '.delete-list', function(e) {
		e.preventDefault();

		// AUTO HIDE SPLASH SCREEN
		$('.splash').addClass('active');

		var leadlistId = $(this).data('listid');
		$.ajax({
			url: 'functions.php',
			type: 'POST',
			data: {
				'data[indicator]': 'delete_list',
				'data[leadlist_id]': leadlistId,
			}
		}).done(function(res) {
			var resp = $.parseJSON(res);

			// AUTO HIDE SPLASH SCREEN
			$('.splash').removeClass('active');

			if (resp.status == true) {
				window.location.href = 'lists.php?token=' + resp.token;
			} else {
				$('#liveToast .toast-body').empty().html(resp.msg);
				$('#liveToast').toast('show');
			}
		});
	});

	// ADD CONTACT
	$('.addcontact-form').validate({
		rules: {
			'data[first_name]': {
				required: true
			},
			'data[last_name]': {
				required: true
			},
			'data[email]': {
				required: true,
				email: true
			},
		},
		messages: {
			'data[first_name]': {
				required: 'Please enter your firstname'
			},
			'data[last_name]': {
				required: 'Please enter your lastname'
			},
			'data[email]': {
				required: 'Need your email to contact',
				email: 'Please enter a valid email'
			},
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var contactData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: contactData
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					window.location.href = 'contacts.php?token=' + resp.token;
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// EDIT CONTACT
	$('.editcontact-form').validate({
		rules: {
			'data[first_name]': {
				required: true
			},
			'data[last_name]': {
				required: true
			},
			'data[email]': {
				required: true,
				email: true
			},
		},
		messages: {
			'data[first_name]': {
				required: 'Please enter your firstname'
			},
			'data[last_name]': {
				required: 'Please enter your lastname'
			},
			'data[email]': {
				required: 'Need your email to contact',
				email: 'Please enter a valid email'
			},
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var contactData = $(form).serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: contactData
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					window.location.href = 'contacts.php?token=' + resp.token;
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// DELETE CONTACT
	$(document).on('click', '.delete-contact', function(e) {
		e.preventDefault();

		// AUTO HIDE SPLASH SCREEN
		$('.splash').addClass('active');

		var prospectId = $(this).data('pid');
		$.ajax({
			url: 'functions.php',
			type: 'POST',
			data: {
				'data[indicator]': 'delete_contact',
				'data[prospect_id]': prospectId,
			}
		}).done(function(res) {
			var resp = $.parseJSON(res);

			// AUTO HIDE SPLASH SCREEN
			$('.splash').removeClass('active');

			if (resp.status == true) {
				window.location.href = 'contacts.php?token=' + resp.token;
			} else {
				$('#liveToast .toast-body').empty().html(resp.msg);
				$('#liveToast').toast('show');
			}
		});
	});

	// SEND EMAIl TO CONTACT
	$('.sendmail-form').validate({
		rules: {
			'data[subject]': {
				required: true
			},
			'data[message]': {
				required: true
			}
		},
		messages: {
			'data[subject]': {
				required: 'Please enter a subject'
			},
			'data[message]': {
				required: 'Please enter your message'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var mailData = new FormData(form);

			// HIDE THE MODAL
			$('#emailModal').modal('hide');

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: mailData,
				cache: false,
			    contentType: false,
			    processData: false
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					var setTim = setTimeout(function() {
						location.reload();
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// SEND EMAIl TO CONTACT
	$('.sendsms-form').validate({
		rules: {
			'data[message]': {
				required: true
			}
		},
		messages: {
			'data[message]': {
				required: 'Please enter your message'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// HIDE THE MODAL
			$('#smsModal').modal('hide');

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var smsData = new FormData(form);

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: smsData,
				cache: false,
			    contentType: false,
			    processData: false
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					var setTim = setTimeout(function() {
						location.reload();
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// SEND BULK EMAIL
	$('.bulkemail-form').validate({
		rules: {
			'data[subject]': {
				required: true
			},
			'data[message]': {
				required: true
			}
		},
		messages: {
			'data[subject]': {
				required: 'Please enter a subject'
			},
			'data[message]': {
				required: 'Please enter your message'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var mailData = new FormData(form);

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: mailData,
				cache: false,
			    contentType: false,
			    processData: false
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					$('.dynamic-subject').val('');
					$('#summernote').summernote('reset');

					var setTim = setTimeout(function() {
						location.reload();
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					$('.dynamic-subject').val('');
					$('#summernote').summernote('reset');
				}
			});
		}
	});

	// SEND BULK SMS
	$('.bulksms-form').validate({
		rules: {
			'data[message]': {
				required: true
			}
		},
		messages: {
			'data[message]': {
				required: 'Please enter your message'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var smsData = new FormData(form);

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: smsData,
				cache: false,
			    contentType: false,
			    processData: false
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					$('.dynamic-message').val('');

					var setTim = setTimeout(function() {
						location.reload();
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// UPLOAD VIDEO STREAM
	$('.uploadstream-form').validate({
		rules: {
			'data[name]': {
				required: true
			}
		},
		messages: {
			'data[name]': {
				required: 'Please enter a name'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			var streamName = $('.stream-name').val();
			uploadVideo(streamName);
			$('.upload-video-section').addClass('d-none');
		}
	});

	// RENDER VIDEO STREAM
	$(document).find('.prerecorded-video').on('change', function(e) {
		e.preventDefault();

		// SHOW SPINNER
		$('.spinner-render').removeClass('d-none');

		var streamData = $('.streaming-form').serialize();
		$.ajax({
			url: 'functions.php',
			type: 'POST',
			data: streamData
		}).done(function(res) {

			var resp = $.parseJSON(res);

			// HIDE SPINNER
			$('.spinner-render').addClass('d-none');

			if (resp.status == true) {
				$('.video-stream').val(resp.sid).focus();
				$('.selected-video').val(resp.name).focus();
			} else {
				$('.video-stream').val('').focus();
				$('.selected-video').val('').focus();
			}
			var validator = $('.videomail-form').validate();
			validator.form();
		});
	});

	// VIDEO BULK MESSAGING
	$('.videomail-form').validate({
		rules: {
			'data[subject]': {
				required: true
			},
			'data[videoname]':{
				required: true
			},
			'data[message]': {
				required: true
			}
		},
		messages: {
			'data[subject]': {
				required: 'Please enter a subject'
			},
			'data[videoname]':{
				required: 'Please select a video'
			},
			'data[message]': {
				required: 'Please enter your message'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET GHB CUSTOMER MAIL
			var videomailData = new FormData(form);

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: videomailData,
				cache: false,
			    contentType: false,
			    processData: false
			}).done(function(res) {
				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					$('.dynamic-subject').val('');
					$('#summernote').summernote('reset');

					var setTim = setTimeout(function() {
						location.reload();
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					$('.dynamic-subject').val('');
					$('#summernote').summernote('reset');
				}
			});
		}
	});

	// RESET EMAIL TEMPLATES
	$('.resetmail-form').validate({
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET NJT CUSTOMER MAIL
			var resetmailData = $('.resetmail-form').serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: resetmailData
			}).done(function(res) {

				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					var setTime = setTimeout(function(){
						location.reload();
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});

	// SCHEDULE AUTO FOLLOW UP
	$(document).on('click', '.btn-followup', function(e) {
		e.preventDefault();

		// AUTO HIDE SPLASH SCREEN
		$('.splash').addClass('active');

		var prospectId = $(this).data('pid');
		var prospectType = $(this).data('type');
		$.ajax({
			url: 'functions.php',
			type: 'POST',
			data: {
				'data[indicator]': 'start_followup',
				'data[prospect_id]': prospectId,
				'data[type]': prospectType
			}
		}).done(function(res) {
			var resp = $.parseJSON(res);

			// AUTO HIDE SPLASH SCREEN
			$('.splash').removeClass('active');

			if (resp.status == true) {
				$('#liveToast .toast-body').empty().html(resp.msg);
				$('#liveToast').toast('show');
				var setTime = setTimeout(function(){
					location.reload();
				}, 3000);
			} else {
				$('#liveToast .toast-body').empty().html(resp.msg);
				$('#liveToast').toast('show');
				var setTime = setTimeout(function(){
					location.reload();
				}, 3000);
			}
		});
	});

	// ADD CONTACT
	$('.editor-form').validate({
		rules: {
			'data[subject_line]': {
				required: true
			}
		},
		messages: {
			'data[subject_line]': {
				required: 'Subject line is required'
			}
		},
		errorElement: "em",
		errorPlacement: function ( error, element ) {
			// Add the `invalid-feedback` class to the error element
			error.addClass("invalid-feedback");

			if (element.prop("type") === "checkbox") {
				error.insertAfter(element.next("label"));
			} else {
				error.insertAfter(element);
			}
		},
		highlight: function (element, errorClass, validClass) {
			$(element).addClass("is-invalid").removeClass("is-valid");
		},
		unhighlight: function (element, errorClass, validClass) {
			$(element).addClass("is-valid").removeClass("is-invalid");
		},
		submitHandler: function(form) {

			event.preventDefault();

			// AUTO HIDE SPLASH SCREEN
			$('.splash').addClass('active');

			// SET NJT CUSTOMER MAIL
			var editorData = $('.editor-form').serialize();

			$.ajax({
				url: 'functions.php',
				type: 'POST',
				data: editorData
			}).done(function(res) {

				var resp = $.parseJSON(res);

				// AUTO HIDE SPLASH SCREEN
				$('.splash').removeClass('active');

				if (resp.status == true) {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
					var setTime = setTimeout(function(){
						location.reload();
					}, 3000);
				} else {
					$('#liveToast .toast-body').empty().html(resp.msg);
					$('#liveToast').toast('show');
				}
			});
		}
	});
});